@@ -167,11 +167,11 @@ Optint_val (value intv, int defval)
 }
 
 value
-guestfs_int_pcre_compile (value anchoredv, value caselessv, value dotallv,
+guestfs_int_pcre_compile (value caselessv, value dotallv,
                           value extendedv, value multilinev,
                           value pattv)
 {
-  CAMLparam5 (anchoredv, caselessv, dotallv, extendedv, multilinev);
+  CAMLparam4 (caselessv, dotallv, extendedv, multilinev);
   CAMLxparam1 (pattv);
   const char *patt;
   int options = 0;
@@ -180,8 +180,6 @@ guestfs_int_pcre_compile (value anchoredv, value caselessv, value dotallv,
   PCRE2_SIZE errnum;
 
   /* Flag parameters are all ‘bool option’, defaulting to false. */
-  if (is_Some_true (anchoredv))
-    options |= PCRE2_ANCHORED;
   if (is_Some_true (caselessv))
     options |= PCRE2_CASELESS;
   if (is_Some_true (dotallv))
@@ -201,16 +199,6 @@ guestfs_int_pcre_compile (value anchoredv, value caselessv, value dotallv,
   CAMLreturn (Val_regexp (re));
 }
 
-/* OCaml calls C functions from bytecode a bit differently when they
- * have more than 5 parameters.
- */
-value
-guestfs_int_pcre_compile_byte (value *argv, int argn)
-{
-  return guestfs_int_pcre_compile (argv[0], argv[1], argv[2], argv[3], argv[4],
-                                   argv[5]);
-}
-
 value
 guestfs_int_pcre_matches (value offsetv, value rev, value strv)
 {
