@@ -32,6 +32,8 @@ let re_rhel_no_minor = PCRE.compile "Red Hat.*release (\\d+)"
 let re_centos_old = PCRE.compile "CentOS.*release (\\d+).*Update (\\d+)"
 let re_centos = PCRE.compile "CentOS.*release (\\d+)\\.(\\d+)"
 let re_centos_no_minor = PCRE.compile "CentOS.*release (\\d+)"
+let re_circle= PCRE.compile "Circle Linux.*release (\\d+)\\.(\\d+)"
+let re_circle_no_minor = PCRE.compile "Circle Linux.*release (\\d+)"
 let re_rocky = PCRE.compile "Rocky Linux.*release (\\d+)\\.(\\d+)"
 let re_rocky_no_minor = PCRE.compile "Rocky Linux.*release (\\d+)"
 let re_scientific_linux_old =
@@ -111,7 +113,7 @@ let rec parse_os_release release_file data =
         * we detect that situation then bail out and use the release
         * files instead.
         *)
-       | { distro = Some (DISTRO_DEBIAN|DISTRO_CENTOS|DISTRO_ROCKY);
+       | { distro = Some (DISTRO_DEBIAN|DISTRO_CENTOS|DISTRO_CIRCLE|DISTRO_ROCKY);
            version = Some (_, 0) } ->
           false
 
@@ -145,6 +147,7 @@ and distro_of_os_release_id = function
   | "altlinux" -> Some DISTRO_ALTLINUX
   | "arch" -> Some DISTRO_ARCHLINUX
   | "centos" -> Some DISTRO_CENTOS
+  | "circle" -> Some DISTRO_CIRCLE
   | "coreos" -> Some DISTRO_COREOS
   | "debian" -> Some DISTRO_DEBIAN
   | "fedora" -> Some DISTRO_FEDORA
@@ -154,6 +157,7 @@ and distro_of_os_release_id = function
   | "kylin" -> Some DISTRO_KYLIN
   | "mageia" -> Some DISTRO_MAGEIA
   | "neokylin" -> Some DISTRO_NEOKYLIN
+  | "openEuler" -> Some DISTRO_OPENEULER
   | "openmandriva" -> Some DISTRO_OPENMANDRIVA
   | "opencloudos" -> Some DISTRO_OPENCLOUDOS
   | "opensuse" -> Some DISTRO_OPENSUSE
@@ -415,6 +419,10 @@ let linux_root_tests : tests = [
                                        DISTRO_CENTOS;
   "/etc/centos-release", parse_generic ~rex:re_centos_no_minor
                                        DISTRO_CENTOS;
+  "/etc/circle-release", parse_generic ~rex:re_circle
+                                       DISTRO_CIRCLE;
+  "/etc/circle-release", parse_generic ~rex:re_circle_no_minor
+                                       DISTRO_CIRCLE;
   "/etc/rocky-release", parse_generic ~rex:re_rocky
                                        DISTRO_ROCKY;
   "/etc/rocky-release", parse_generic ~rex:re_rocky_no_minor
@@ -434,6 +442,10 @@ let linux_root_tests : tests = [
                                        DISTRO_CENTOS;
   "/etc/redhat-release", parse_generic ~rex:re_centos_no_minor
                                        DISTRO_CENTOS;
+  "/etc/redhat-release", parse_generic ~rex:re_circle
+                                       DISTRO_CIRCLE;
+  "/etc/redhat-release", parse_generic ~rex:re_circle_no_minor
+                                       DISTRO_CIRCLE;
   "/etc/redhat-release", parse_generic ~rex:re_rocky
                                        DISTRO_ROCKY;
   "/etc/redhat-release", parse_generic ~rex:re_rocky_no_minor
