@@ -456,58 +456,6 @@ do_part_set_mbr_id (const char *device, int partnum, int idbyte)
   return 0;
 }
 
-int
-do_part_set_gpt_type (const char *device, int partnum, const char *guid)
-{
-  if (partnum <= 0) {
-    reply_with_error ("partition number must be >= 1");
-    return -1;
-  }
-
-  CLEANUP_FREE char *typecode = NULL;
-  if (asprintf (&typecode, "%i:%s", partnum, guid) == -1) {
-    reply_with_perror ("asprintf");
-    return -1;
-  }
-
-  CLEANUP_FREE char *err = NULL;
-  int r = commandf (NULL, &err, COMMAND_FLAG_FOLD_STDOUT_ON_STDERR,
-                    "sgdisk", device, "-t", typecode, NULL);
-
-  if (r == -1) {
-    reply_with_error ("%s %s -t %s: %s", "sgdisk", device, typecode, err);
-    return -1;
-  }
-
-  return 0;
-}
-
-int
-do_part_set_gpt_guid (const char *device, int partnum, const char *guid)
-{
-  if (partnum <= 0) {
-    reply_with_error ("partition number must be >= 1");
-    return -1;
-  }
-
-  CLEANUP_FREE char *typecode = NULL;
-  if (asprintf (&typecode, "%i:%s", partnum, guid) == -1) {
-    reply_with_perror ("asprintf");
-    return -1;
-  }
-
-  CLEANUP_FREE char *err = NULL;
-  int r = commandf (NULL, &err, COMMAND_FLAG_FOLD_STDOUT_ON_STDERR,
-                    "sgdisk", device, "-u", typecode, NULL);
-
-  if (r == -1) {
-    reply_with_error ("%s %s -u %s: %s", "sgdisk", device, typecode, err);
-    return -1;
-  }
-
-  return 0;
-}
-
 char *
 do_part_get_name (const char *device, int partnum)
 {
@@ -564,95 +512,3 @@ do_part_get_name (const char *device, int partnum)
     return NULL;
   }
 }
-
-static char *
-extract_uuid (const char *value)
-{
-  /* The value contains only valid GUID characters */
-  const size_t value_len = strspn (value, "-0123456789ABCDEF");
-
-  char *ret = malloc (value_len + 1);
-  if (ret == NULL) {
-    reply_with_perror ("malloc");
-    return NULL;
-  }
-
-  memcpy (ret, value, value_len);
-  ret[value_len] = '\0';
-  return ret;
-}
-
-char *
-do_part_get_disk_guid (const char *device)
-{
-  const char *pattern = "Disk identifier (GUID):";
-  size_t i;
-
-  CLEANUP_FREE char *err = NULL;
-  int r = commandf (NULL, &err, COMMAND_FLAG_FOLD_STDOUT_ON_STDERR,
-                    "sgdisk", device, "-p", NULL);
-  if (r == -1) {
-    reply_with_error ("%s %s -p: %s", "sgdisk", device, err);
-    return NULL;
-  }
-
-  CLEANUP_FREE_STRING_LIST char **lines = split_lines (err);
-  if (lines == NULL) {
-    reply_with_error ("'%s %s -p' returned no output",
-                      "sgdisk", device);
-    return NULL;
-  }
-
-  for (i = 0; lines[i] != NULL; ++i) {
-    if (STRPREFIX (lines[i], pattern)) {
-      char *value = lines[i] + strlen (pattern);
-
-      /* Skip any leading whitespace */
-      value += strspn (value, " \t");
-
-      /* Extract the actual information from the field. */
-      char *ret = extract_uuid (value);
-      if (ret == NULL) {
-        /* The extraction function already sends the error. */
-        return NULL;
-      }
-
-      return ret;
-    }
-  }
-
-  /* If we got here it means we didn't find the field */
-  reply_with_error ("sgdisk output did not contain disk GUID. "
-                    "See LIBGUESTFS_DEBUG output for more details");
-  return NULL;
-}
-
-int
-do_part_set_disk_guid (const char *device, const char *guid)
-{
-  CLEANUP_FREE char *err = NULL;
-  int r = commandf (NULL, &err, COMMAND_FLAG_FOLD_STDOUT_ON_STDERR,
-                    "sgdisk", device, "-U", guid, NULL);
-
-  if (r == -1) {
-    reply_with_error ("%s %s -U %s: %s", "sgdisk", device, guid, err);
-    return -1;
-  }
-
-  return 0;
-}
-
-int
-do_part_set_disk_guid_random (const char *device)
-{
-  CLEANUP_FREE char *err = NULL;
-  int r = commandf (NULL, &err, COMMAND_FLAG_FOLD_STDOUT_ON_STDERR,
-                    "sgdisk", device, "-U", "R", NULL);
-
-  if (r == -1) {
-    reply_with_error ("%s %s -U R: %s", "sgdisk", device, err);
-    return -1;
-  }
-
-  return 0;
-}
