@@ -1,5 +1,5 @@
 /* guestfish - guest filesystem shell
- * Copyright (C) 2009-2020 Red Hat Inc.
+ * Copyright (C) 2009-2023 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,7 +90,6 @@ static int pipe_error = 0;
 guestfs_h *g = NULL;
 
 int read_only = 0;
-int live = 0;
 int quit = 0;
 int verbose = 0;
 int remote_control_listen = 0;
@@ -117,7 +116,7 @@ usage (int status)
   else {
     printf (_("%s: guest filesystem shell\n"
               "%s lets you edit virtual machine filesystems\n"
-              "Copyright (C) 2009-2020 Red Hat Inc.\n"
+              "Copyright (C) 2009-2023 Red Hat Inc.\n"
               "Usage:\n"
               "  %s [--options] cmd [: cmd : cmd ...]\n"
               "Options:\n"
@@ -137,7 +136,6 @@ usage (int status)
               "  --key selector       Specify a LUKS key\n"
               "  --keys-from-stdin    Read passphrases from stdin\n"
               "  --listen             Listen for remote commands\n"
-              "  --live               Connect to a live virtual machine\n"
               "  -m|--mount dev[:mnt[:opts[:fstype]]]\n"
               "                       Mount dev on mnt (if omitted, /)\n"
               "  --network            Enable network\n"
@@ -292,7 +290,8 @@ main (int argc, char *argv[])
       } else if (STREQ (long_options[option_index].name, "csh")) {
         remote_control_csh = 1;
       } else if (STREQ (long_options[option_index].name, "live")) {
-        live = 1;
+        error (EXIT_FAILURE, 0,
+               _("libguestfs live support was removed in libguestfs 1.48"));
       } else if (STREQ (long_options[option_index].name, "pipe-error")) {
         pipe_error = 1;
       } else if (STREQ (long_options[option_index].name, "network")) {
@@ -477,6 +476,9 @@ main (int argc, char *argv[])
   /* If we've got drives to add, add them now. */
   add_drives (drvs);
 
+  if (key_store_requires_network (ks) && guestfs_set_network (g, 1) == -1)
+    exit (EXIT_FAILURE);
+
   /* If we've got mountpoints or prepared drives or -i option, we must
    * launch the guest and mount them.
    */
