@@ -1,5 +1,5 @@
 (* libguestfs
- * Copyright (C) 2009-2020 Red Hat Inc.
+ * Copyright (C) 2009-2023 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,7 +73,8 @@ of C<guestfs_add_drive_ro>." };
     shortdesc = "add a drive specifying the QEMU block emulation to use";
     longdesc = "\
 This is the same as C<guestfs_add_drive> but it allows you
-to specify the QEMU interface emulation to use at run time." };
+to specify the QEMU interface emulation to use at run time.
+Both the direct and the libvirt backends ignore C<iface>." };
 
   { defaults with
     name = "add_drive_ro_with_if"; added = (1, 0, 84);
@@ -83,7 +84,8 @@ to specify the QEMU interface emulation to use at run time." };
     shortdesc = "add a drive read-only specifying the QEMU block emulation to use";
     longdesc = "\
 This is the same as C<guestfs_add_drive_ro> but it allows you
-to specify the QEMU interface emulation to use at run time." };
+to specify the QEMU interface emulation to use at run time.
+Both the direct and the libvirt backends ignore C<iface>." };
 
   { defaults with
     name = "lstatlist"; added = (1, 0, 77);
@@ -137,6 +139,15 @@ refers to.
 
 This is the same as the L<lstat(2)> system call." };
 
+  { defaults with
+    name = "remove_drive"; added = (1, 19, 49);
+    style = RErr, [String (PlainString, "label")], [];
+    deprecated_by = Deprecated_no_replacement;
+    blocking = false;
+    shortdesc = "remove a disk image";
+    longdesc = "\
+This call does nothing and returns an error." };
+
 ]
 
 let daemon_functions = [
@@ -899,4 +910,21 @@ C<device> parameter must be the name of the LUKS mapping
 device (ie. F</dev/mapper/mapname>) and I<not> the name
 of the underlying block device." };
 
+  { defaults with
+    name = "list_9p"; added = (1, 11, 12);
+    style = RStringList (RPlainString, "mounttags"), [], [];
+    shortdesc = "list 9p filesystems";
+    deprecated_by = Deprecated_no_replacement;
+    longdesc = "\
+This call does nothing and returns an error." };
+
+  { defaults with
+    name = "mount_9p"; added = (1, 11, 12);
+    style = RErr, [String (PlainString, "mounttag"); String (PlainString, "mountpoint")], [OString "options"];
+    camel_name = "Mount9P";
+    deprecated_by = Deprecated_no_replacement;
+    shortdesc = "mount 9p filesystem";
+    longdesc = "\
+This call does nothing and returns an error." };
+
 ]
