@@ -178,6 +178,10 @@ Buildroot-derived distro, but not one we specifically recognize.
 
 CentOS.
 
+=item \"circle\"
+
+Circle Linux.
+
 =item \"cirros\"
 
 Cirros.
@@ -250,6 +254,10 @@ NetBSD.
 
 OpenBSD.
 
+=item \"openeuler\"
+
+openEuler.
+
 =item \"openmandriva\"
 
 OpenMandriva Lx.
