@@ -1,5 +1,5 @@
 (* libguestfs
- * Copyright (C) 2009-2019 Red Hat Inc.
+ * Copyright (C) 2009-2023 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,10 @@ let rec generate_c_api_tests () =
   pr "\
 #include <config.h>
 
+/* It is safe to call deprecated functions from this file. */
+#define GUESTFS_NO_WARN_DEPRECATED
+#undef GUESTFS_NO_DEPRECATED
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -52,12 +56,6 @@ let rec generate_c_api_tests () =
 
 #include \"tests.h\"
 
-#ifdef __linux__
-#define GUESTFS_ISO_SYSTEM_ID \"LINUX\"
-#else
-#error Missing GUESTFS_ISO_SYSTEM_ID for the current OS
-#endif
-
 ";
 
   (* Generate a list of commands which are not tested anywhere. *)
