@@ -1,31 +1,30 @@
 /* Accept a connection on a socket, with specific opening flags.
-   Copyright (C) 2009-2021 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation, either version 3 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with this program; if not, see <https://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
+#ifndef HAVE_ACCEPT4
+
 /* Specification.  */
 #include <sys/socket.h>
 
 #include <errno.h>
 #include <fcntl.h>
-#include "binary-io.h"
 #if GNULIB_MSVC_NOTHROW
 # include "msvc-nothrow.h"
-#else
-# include <io.h>
 #endif
 
 #ifndef SOCK_CLOEXEC
@@ -35,31 +34,18 @@
 # define SOCK_NONBLOCK 0
 #endif
 
+#ifndef O_TEXT
+#define O_TEXT 0
+#endif
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 int
 accept4 (int sockfd, struct sockaddr *addr, socklen_t *addrlen, int flags)
 {
   int fd;
 
-#if HAVE_DECL_ACCEPT4
-# undef accept4
-  /* Try the system call first, if it exists.  (We may be running with a glibc
-     that has the function but with an older kernel that lacks it.)  */
-  {
-    /* Cache the information whether the system call really exists.  */
-    static int have_accept4_really; /* 0 = unknown, 1 = yes, -1 = no */
-    if (have_accept4_really >= 0)
-      {
-        int result = accept4 (sockfd, addr, addrlen, flags);
-        if (!(result < 0 && errno == ENOSYS))
-          {
-            have_accept4_really = 1;
-            return result;
-          }
-        have_accept4_really = -1;
-      }
-  }
-#endif
-
   /* Check the supported flags.  */
   if ((flags & ~(SOCK_CLOEXEC | SOCK_NONBLOCK | O_TEXT | O_BINARY)) != 0)
     {
@@ -149,3 +135,5 @@ accept4 (int sockfd, struct sockaddr *addr, socklen_t *addrlen, int flags)
 
   return fd;
 }
+
+#endif /* !HAVE_ACCEPT4 */
