@@ -1,5 +1,5 @@
 /* libguestfs
- * Copyright (C) 2013-2020 Red Hat Inc.
+ * Copyright (C) 2013-2023 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -116,16 +116,20 @@ is_zero (const char *buffer, size_t size)
 #define COMPILE_REGEXP(name,pattern,options)                            \
   static void compile_regexp_##name (void) __attribute__((constructor)); \
   static void free_regexp_##name (void) __attribute__((destructor));    \
-  static pcre *name;                                                    \
+  static pcre2_code *name;                                              \
                                                                         \
   static void                                                           \
   compile_regexp_##name (void)                                          \
   {                                                                     \
-    const char *err;                                                    \
-    int offset;                                                         \
-    name = pcre_compile ((pattern), (options), &err, &offset, NULL);    \
+    int errnum;                                                         \
+    PCRE2_SIZE offset;                                                  \
+    name = pcre2_compile ((PCRE2_SPTR)(pattern),                        \
+                          PCRE2_ZERO_TERMINATED,                        \
+                          (options), &errnum, &offset, NULL);           \
     if (name == NULL) {                                                 \
-      ignore_value (write (2, err, strlen (err)));                      \
+      PCRE2_UCHAR err[256];                                             \
+      pcre2_get_error_message (errnum, err, sizeof err);                \
+      ignore_value (write (2, err, strlen ((char *)err)));              \
       abort ();                                                         \
     }                                                                   \
   }                                                                     \
@@ -133,7 +137,7 @@ is_zero (const char *buffer, size_t size)
   static void                                                           \
   free_regexp_##name (void)                                             \
   {                                                                     \
-    pcre_free (name);                                                   \
+    pcre2_code_free (name);                                             \
   }
 
 /* The type field of a parsed mountable.
@@ -148,4 +152,16 @@ typedef enum {
   MOUNTABLE_PATH        /* An already mounted path: device = path */
 } mountable_type_t;
 
+/* Some functions replaced by gnulib */
+#ifndef HAVE_ACCEPT4
+#include <sys/socket.h>
+
+extern int accept4 (int sockfd, struct sockaddr *__restrict__ addr,
+		    socklen_t *__restrict__ addrlen, int flags);
+#endif
+
+#ifndef HAVE_PIPE2
+extern int pipe2 (int pipefd[2], int flags);
+#endif
+
 #endif /* GUESTFS_INTERNAL_ALL_H_ */
