@@ -97,7 +97,6 @@ xmlBufferDetach (xmlBufferPtr buf)
 }
 #endif
 
-#ifdef HAVE_ATTRIBUTE_CLEANUP
 #define CLEANUP_VIRSECRETFREE __attribute__((cleanup(cleanup_virSecretFree)))
 
 static void
@@ -108,10 +107,6 @@ cleanup_virSecretFree (void *ptr)
     virSecretFree (secret_obj);
 }
 
-#else /* !HAVE_ATTRIBUTE_CLEANUP */
-#define CLEANUP_VIRSECRETFREE
-#endif
-
 /* List used to store a mapping of secret to libvirt secret UUID. */
 struct secret {
   char *secret;
