@@ -16,4 +16,4 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-exec $srcdir/run-test.pl xattrs direct
+exec $srcdir/selinux/run-test.pl xattrs direct
